==> haskell-lucid-2.9.11-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lucid
version: 2.9.11
id: lucid-2.9.11-KdGhVPzozKj6NMtpcpDFps
key: lucid-2.9.11-KdGhVPzozKj6NMtpcpDFps
license: BSD-3-Clause
copyright: 2014-2017 Chris Done
maintainer: chrisdone@gmail.com, oleg.grenrus@iki.fi
author: Chris Done
homepage: https://github.com/chrisdone/lucid
synopsis: Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.
    .
    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)
    .
    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')
    .
    * For more, read <https://chrisdone.com/posts/lucid the blog post>
    .
    See the "Lucid" module for more documentation.
category: Web
abi: 663f6c5deae7898cb72da9471bd2f3fa
exposed: True
exposed-modules:
    Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs: /usr/lib/ghc-8.6.4/site-local/lucid-2.9.11
library-dirs: /usr/lib/ghc-8.6.4/site-local/lucid-2.9.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/lucid-2.9.11
hs-libraries: HSlucid-2.9.11-KdGhVPzozKj6NMtpcpDFps
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    bytestring-0.10.8.2 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    mmorph-1.1.2-77bUylhsXfN4I9bNGFKrpb mtl-2.2.2 text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html: /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lucid-2.9.11-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lucid
version: 2.9.11
id: lucid-2.9.11-Bqi4P4G64cwDbJMaxR6E0i
key: lucid-2.9.11-Bqi4P4G64cwDbJMaxR6E0i
license: BSD-3-Clause
copyright: 2014-2017 Chris Done
maintainer: chrisdone@gmail.com, oleg.grenrus@iki.fi
author: Chris Done
homepage: https://github.com/chrisdone/lucid
synopsis: Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.
    .
    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)
    .
    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')
    .
    * For more, read <https://chrisdone.com/posts/lucid the blog post>
    .
    See the "Lucid" module for more documentation.
category: Web
abi: 2e43591ccd41f251f7357bf40e984858
exposed: True
exposed-modules:
    Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs: /usr/lib/ghc-8.6.4/site-local/lucid-2.9.11
library-dirs: /usr/lib/ghc-8.6.4/site-local/lucid-2.9.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/lucid-2.9.11
hs-libraries: HSlucid-2.9.11-Bqi4P4G64cwDbJMaxR6E0i
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    bytestring-0.10.8.2 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    mmorph-1.1.2-Er9xBGV38q7IO8C42uR2nT mtl-2.2.2 text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html: /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
